#!/usr/bin/tclsh
# Copyright (c) 2002-2003, Steve McMillen
# All Rights Reservered
#
# Steve McMillen
# stevemc@real.com
#
# Helix Producer Remote Encoder Sample v1.0 August 7, 2003
#
# Script to upload job files to job library
#
# This code is freely distributable without restriction, but is provided as-is 
# with no waranty expressed or implied. 
#

source options.cfg
set debug 0

proc PrintForm { {filename ""} } {
	global ScriptsDir
	puts "Content-Type: text/html\n"
	puts "
	<html>
	<body>
	<h2>Add job to library</h2>"

	if {$filename != ""} {
		puts "<p style=color:red;>Filename $filename already in library.	Please rename file before uploading.</p>"
	}

	puts "
	<form method=POST action=$ScriptsDir/add.tcl enctype=multipart/form-data>
		<p>Job File: <input type=file name=jobfile size=20></p>
		<!-- <p>Description: <input type=text name=description size=20></p> -->
	<p><input type=submit value=Upload></p>
	</form>
	</body>
	</html>"
}


proc AddJobFile { } {
	global env debug JobLibraryDir

	# Get CONTENT_TYPE env variable and search for boundary value.
	# We know CONTENT_TYPE exists because we are expexting only a POST from a form.
	# We know boundary exists because we are expexting only multipart/form-data POST
	regexp -- {boundary=(.*)$} "$env(CONTENT_TYPE)" all boundary
	# not quite sure why but boundary is always preceeded by two dashes (--)
	set boundary "--$boundary"

	# Read input and store in variable
	set input [read stdin]
	if $debug {puts "Unparsed Multipart Form Data:\n$input"}


	# Split the input on the boundary obtained above
	 # Use for loop in case form has multiple documents (current form only supports 1)
	foreach {all part} [regexp -inline -all "\n(.*?)\n$boundary" $input] {
		regexp {(.*?)\n\n(.*)$} $part all headers body
		# Extract info from useful headers (we only care about Content-Disposition)
		foreach line [split $headers \n] {
			if [string match "Content-Disposition:*" $line] {
				if {![regexp { name="([^"]*)"} $line all name]} {set name ""}
				regexp { filename="([^"]*)"} $line all filename
			}
		}
		if [info exists filename] {
			# Swap windows-style path separators for unix-style separators
			regsub -all {\\} $filename "/" filename
				# Remove the path from the filename
			set filename [file tail $filename]

				# Test to see if filename exists already.	If it does, send user back to the form 
				# with the fielname populated and a warning telling user to rename file before uploading.
				if [file exists "$JobLibraryDir/$filename"] {
				PrintForm $filename
				exit
			}

				# Open the file for reading.	Use catch in case there are errors.
			if [catch {open "$JobLibraryDir/$filename" w} result] {
					# If there was an error, then print error and exit.
				puts "Content-Type: text/plain\n"
				puts "ERROR: $result"
				exit
			} else {
				# Else, file was opened and result is the fileID
				set fileID $result
			}
				# Write uploaded file to disk
			# Remote windows extra newline characters from the file
			regsub -all {\r} $body "" body
			puts $fileID "$body"
			close $fileID
			if $debug {puts "filename=$filename"}
			if $debug {puts "PART=$body"}
		} else {
			set $name "$body"
			if $debug {puts "$name=$body"}
		}
		catch {unset headers body name filename}
	}

	# If we successfully added the job, then print existing jobs
	source library.tcl
}


if [info exists env(CONTENT_TYPE)] {
	AddJobFile
} else {
	PrintForm
}
