#!/usr/bin/tclsh
# Copyright (c) 2002-2003, Steve McMillen
# All Rights Reservered
#
# Steve McMillen
# stevemc@real.com
#
# Helix Producer Remote Encoder Sample v1.0 August 7, 2003
#
# Script to print a list of available media files in the source or encoded directories and links to play or download those files
#
# This code is freely distributable without restriction, but is provided as-is 
# with no waranty expressed or implied. 
#

source options.cfg

# Source in cgi parameters
source cgi-lib.tcl
set dir "$cgi(dir)"
set url "$cgi(url)"
set type "$cgi(type)"

proc Round {val digits} {
	if {$digits == 0} {return [expr round($val)]}
	set digits [expr pow(10,$digits)]
	return [expr round($digits*$val)/$digits]
}

proc PrettySize {size} {
  if {$size<1e3} {return "$size b" } \
  elseif {$size<1e5} {return "[expr [Round $size/1e3 1]] kB" } \
  elseif {$size<1e6} {return "[expr [Round $size/1e3 0]] kB" } \
  elseif {$size<1e8} {return "[expr [Round $size/1e6 1]] MB" } \
  elseif {$size<1e9} {return "[expr [Round $size/1e6 0]] MB" } \
  elseif {$size<1e11} {return "[expr [Round $size/1e9 1]] GB" } \
  else {return "[expr [Round $size/1e9 0]] GB" }
}

set filenames [glob -nocomplain "$dir/*"]

puts "Content-Type: text/html\n"

if [llength $filenames] {
	puts "<p>Listing for directory $dir</p>"
	puts "<table>"
	puts "<tr><td nowrap><b>Filename</b></td><td nowrap><b>File Size</b></td>"
	if { $type == "source" }  {puts "<td nowrap><b>File Path</b> (Can be pasted into input of job files)</td>"}
	puts "</tr>"
	foreach filename $filenames {
	    set filesize [PrettySize [file size "$filename"]]
		 set wholename $filename
	    set filename [file tail "$filename"]
	    puts "<tr><td nowrap><a href=$ScriptsDir/ramgen.tcl?filename=$url/$filename>$filename</a></td>"
		 puts "<td nowrap>$filesize</td>"
	    if { $type == "source" }  {puts "<td nowrap>$dir/$filename</td>"}
		 puts "</tr>"
	}
	puts "</table>"
} else {
	puts "No files found in $dir."
}

